You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@myfaces.apache.org by ta...@apache.org on 2020/08/11 09:02:00 UTC

[myfaces] branch master updated: higher initial size

This is an automated email from the ASF dual-hosted git repository.

tandraschko pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/myfaces.git


The following commit(s) were added to refs/heads/master by this push:
     new 9b902c8  higher initial size
9b902c8 is described below

commit 9b902c8211c4b157ceb6e04d77f98f4852fd2cd4
Author: Thomas Andraschko <ta...@apache.org>
AuthorDate: Tue Aug 11 11:01:52 2020 +0200

    higher initial size
---
 impl/src/main/java/org/apache/myfaces/config/MyfacesConfig.java | 5 ++---
 1 file changed, 2 insertions(+), 3 deletions(-)

diff --git a/impl/src/main/java/org/apache/myfaces/config/MyfacesConfig.java b/impl/src/main/java/org/apache/myfaces/config/MyfacesConfig.java
index fd61802..bb012ee 100755
--- a/impl/src/main/java/org/apache/myfaces/config/MyfacesConfig.java
+++ b/impl/src/main/java/org/apache/myfaces/config/MyfacesConfig.java
@@ -222,17 +222,16 @@ public class MyfacesConfig
     
     /**
      * Set the size of the cache used to store strings generated using SectionUniqueIdCounter
      * for component ids. If this is set to 0, no cache is used. By default is set to 100.
      */
     @JSFWebConfigParam(defaultValue = "100", since = "2.0.13, 2.1.7",
             group="viewhandler", tags="performance")
     public static final String COMPONENT_UNIQUE_IDS_CACHE_SIZE =
         "org.apache.myfaces.COMPONENT_UNIQUE_IDS_CACHE_SIZE";
-    private static final int COMPONENT_UNIQUE_IDS_CACHE_SIZE_DEFAULT = 100;
+    private static final int COMPONENT_UNIQUE_IDS_CACHE_SIZE_DEFAULT = 200;
 
     /**
     * If set false, myfaces won't support JSP. JSP are deprecated in JSF 2.X. Default value is true. 
-    * 
     * If this property is set is false, all related logic for JSP is skipped.
     */
     @JSFWebConfigParam(since="2.0.13,2.1.7", expectedValues="true,false", defaultValue="true",
@@ -222,17 +222,16 @@ public class MyfacesConfig
     /**
      * Set the size of the cache used to store strings generated using SectionUniqueIdCounter
-     * for component ids. If this is set to 0, no cache is used. By default is set to 100.
+     * for component ids. If this is set to 0, no cache is used. By default is set to 200.
      */
     @JSFWebConfigParam(defaultValue = "100", since = "2.0.13, 2.1.7",